@@ -6,6 +6,7 @@ This module contains tests for Story Arc objects.
 import pytest
 
 from simyan.exceptions import APIError
+from simyan.session import Session as Comicvine
 
 FIRST_ISSUE_ID = 155207
 ID = 55766
@@ -14,7 +15,7 @@ NAME = "Blackest Night"
 PUBLISHER_ID = 10
 
 
-def test_story_arc(comicvine):
+def test_story_arc(comicvine: Comicvine):
     """Test for known arcs."""
     result = comicvine.story_arc(ID)
     assert result.first_issue.id == FIRST_ISSUE_ID
@@ -25,13 +26,13 @@ def test_story_arc(comicvine):
     assert result.publisher.id == PUBLISHER_ID
 
 
-def test_story_arc_fail(comicvine):
+def test_story_arc_fail(comicvine: Comicvine):
     """Test for bad arc requests."""
     with pytest.raises(APIError):
         comicvine.story_arc(-1)
 
 
-def test_story_arc_list(comicvine):
+def test_story_arc_list(comicvine: Comicvine):
     """Test for StoryArcList."""
     search_results = comicvine.story_arc_list({"filter": f"name:{NAME}"})
     result = [x for x in search_results if x.id == ID][0]
@@ -42,7 +43,7 @@ def test_story_arc_list(comicvine):
     assert result.publisher.id == PUBLISHER_ID
 
 
-def test_story_arc_list_empty(comicvine):
+def test_story_arc_list_empty(comicvine: Comicvine):
     """Test StoryArcList with no results."""
     results = comicvine.story_arc_list({"filter": "name:INVALID"})
     assert len(results) == 0
